==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels.md <==
# AwsWafLabels


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels')
```



| Illustration | AwsWafLabels | AwsWafLabelsCard | AwsWafLabelsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels.png) | ![illustration for AwsWafLabels](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels.Local.png) | ![illustration for AwsWafLabelsCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabelsCard.Local.png) | ![illustration for AwsWafLabelsGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabelsGroup.Local.png) |




## AwsWafLabels

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsWafLabels
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels')

' renders the element
AwsWafLabels('AwsWafLabels', 'Aws Waf Labels', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsWafLabels
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels')

' renders the element
AwsWafLabels('AwsWafLabels', 'Aws Waf Labels', 'an optional tech label')
@enduml
```

## AwsWafLabelsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsWafLabelsCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels')

' renders the element
AwsWafLabelsCard('AwsWafLabelsCard', 'Aws Waf Labels Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsWafLabelsCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels')

' renders the element
AwsWafLabelsCard('AwsWafLabelsCard', 'Aws Waf Labels Card', 'an optional description')
@enduml
```

## AwsWafLabelsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsWafLabelsGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels')

' renders the element
AwsWafLabelsGroup('AwsWafLabelsGroup', 'Aws Waf Labels Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsWafLabelsGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels')

' renders the element
AwsWafLabelsGroup('AwsWafLabelsGroup', 'Aws Waf Labels Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels.md <==
# AwsWafLabels


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels')
```



| Illustration | AwsWafLabels | AwsWafLabelsCard | AwsWafLabelsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels.png) | ![illustration for AwsWafLabels](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels.Local.png) | ![illustration for AwsWafLabelsCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabelsCard.Local.png) | ![illustration for AwsWafLabelsGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabelsGroup.Local.png) |




## AwsWafLabels

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsWafLabels
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels')

' renders the element
AwsWafLabels('AwsWafLabels', 'Aws Waf Labels', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsWafLabels
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels')

' renders the element
AwsWafLabels('AwsWafLabels', 'Aws Waf Labels', 'an optional tech label')
@enduml
```

## AwsWafLabelsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsWafLabelsCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels')

' renders the element
AwsWafLabelsCard('AwsWafLabelsCard', 'Aws Waf Labels Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsWafLabelsCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels')

' renders the element
AwsWafLabelsCard('AwsWafLabelsCard', 'Aws Waf Labels Card', 'an optional description')
@enduml
```

## AwsWafLabelsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsWafLabelsGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels')

' renders the element
AwsWafLabelsGroup('AwsWafLabelsGroup', 'Aws Waf Labels Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsWafLabelsGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsWafLabels')

' renders the element
AwsWafLabelsGroup('AwsWafLabelsGroup', 'Aws Waf Labels Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
